.. _hydra-zen-explanation:

Explanation
===========

Articles and posts about topics relevant -- directly or indirectly -- to hydra-zen and 
Hydra.

.. toctree::
   :maxdepth: 1
   :caption: Contents:

   explanation/type_refinement
   explanation/dont_repeat_yourself
   explanation/hydrated_dataclass
